@@ -9,7 +9,7 @@
  */
 namespace SebastianBergmann\CodeCoverage;
 
-use SebastianBergmann\CodeCoverage\RawCodeCoverageData;
+use SebastianBergmann\CodeCoverage\Data\RawCodeCoverageData;
 use function array_merge;
 use function range;
 use function rmdir;
@@ -1013,7 +1013,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls(...$data));
+             ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1021,39 +1021,44 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(6, 9)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(27, 32)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(20, 25)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'BankAccount.php' => array_merge(
                     range(6, 9),
@@ -1075,7 +1080,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub->method('collectsBranchAndPathCoverage')->willReturn(true);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls(...$data));
+             ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1083,39 +1088,44 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(6, 9)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(27, 32)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(20, 25)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'BankAccount.php' => array_merge(
                     range(6, 9),
@@ -1137,7 +1147,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub->method('collectsBranchAndPathCoverage')->willReturn(true);
 
         $stub->method('stop')
-            ->will($this->onConsecutiveCalls(...$data));
+            ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'source_without_namespace.php');
@@ -1146,6 +1156,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
         $coverage->start(
             'faketest',
+            null,
             true
         );
 
@@ -1213,7 +1224,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls(...$data));
+             ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'NamespacedBankAccount.php');
@@ -1221,39 +1232,44 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'NamespacedBankAccount.php' => range(11, 14)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'NamespacedBankAccount.php' => range(32, 37)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'NamespacedBankAccount.php' => range(25, 30)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'NamespacedBankAccount.php' => array_merge(
                     range(11, 14),
@@ -1273,7 +1289,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls(...$data));
+             ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1281,21 +1297,24 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(6, 9)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(27, 32)]
         );
 
@@ -1309,7 +1328,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls($data[2], $data[3]));
+             ->willReturn($data[2], $data[3]);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1317,20 +1336,22 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(20, 25)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'BankAccount.php' => array_merge(
                     range(6, 9),
@@ -1410,7 +1431,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls(...$data));
+             ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1418,21 +1439,24 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(6, 9)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(27, 32)]
         );
 
@@ -1446,7 +1470,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-             ->will($this->onConsecutiveCalls($data[2], $data[3]));
+             ->willReturn($data[2], $data[3]);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1454,20 +1478,22 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage = new CodeCoverage($stub, $filter);
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(20, 25)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'BankAccount.php' => array_merge(
                     range(6, 9),
@@ -1693,7 +1719,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
             $filter
         );
 
-        $coverage->start('FileWithIgnoredLines', true);
+        $coverage->start('FileWithIgnoredLines', null, true);
         $coverage->stop();
 
         return $coverage;
@@ -1727,7 +1753,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
             $filter
         );
 
-        $coverage->start('FileWithEval', true);
+        $coverage->start('FileWithEval', null, true);
         $coverage->stop();
 
         return $coverage;
@@ -1763,7 +1789,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
             $filter
         );
 
-        $coverage->start('ClassWithAnonymousFunction', true);
+        $coverage->start('ClassWithAnonymousFunction', null, true);
         $coverage->stop();
 
         return $coverage;
@@ -1803,7 +1829,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
             $filter
         );
 
-        $coverage->start('ClassWithOutsideFunction', true);
+        $coverage->start('ClassWithOutsideFunction', null, true);
         $coverage->stop();
 
         return $coverage;
@@ -1849,7 +1875,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-            ->will($this->onConsecutiveCalls(...$data));
+            ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1859,39 +1885,44 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage->includeUncoveredFiles();
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(6, 9)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(27, 32)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(20, 25)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'BankAccount.php' => array_merge(
                     range(6, 9),
@@ -1911,7 +1942,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $stub = $this->createStub(Driver::class);
 
         $stub->method('stop')
-            ->will($this->onConsecutiveCalls(...$data));
+            ->willReturn(...$data);
 
         $filter = new Filter;
         $filter->includeFile(TEST_FILES_PATH . 'BankAccount.php');
@@ -1921,39 +1952,44 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $coverage->excludeUncoveredFiles();
 
         $coverage->start(
-            new BankAccountTest('testBalanceIsInitiallyZero'),
+            'BankAccountTest::testBalanceIsInitiallyZero',
+            null,
             true
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(6, 9)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative')
+            'BankAccountTest::testBalanceCannotBecomeNegative'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(27, 32)]
         );
 
         $coverage->start(
-            new BankAccountTest('testBalanceCannotBecomeNegative2')
+            'BankAccountTest::testBalanceCannotBecomeNegative2'
         );
 
         $coverage->stop(
             true,
+            null,
             [TEST_FILES_PATH . 'BankAccount.php' => range(20, 25)]
         );
 
         $coverage->start(
-            new BankAccountTest('testDepositWithdrawMoney')
+            'BankAccountTest::testDepositWithdrawMoney'
         );
 
         $coverage->stop(
             true,
+            null,
             [
                 TEST_FILES_PATH . 'BankAccount.php' => array_merge(
                     range(6, 9),
