@@ -10,19 +10,16 @@
 namespace SebastianBergmann\CodeCoverage;
 
 use function array_fill;
+use PHPUnit\Framework\Attributes\CoversClass;
+use SebastianBergmann\CodeCoverage\Data\RawCodeCoverageData;
 use SebastianBergmann\CodeCoverage\Driver\Driver;
 use SebastianBergmann\CodeCoverage\Driver\Selector;
 use SebastianBergmann\Environment\Runtime;
 
-/**
- * @covers \SebastianBergmann\CodeCoverage\CodeCoverage
- */
+#[CoversClass(CodeCoverage::class)]
 final class CodeCoverageTest extends TestCase
 {
-    /**
-     * @var CodeCoverage
-     */
-    private $coverage;
+    private CodeCoverage $coverage;
 
     protected function setUp(): void
     {
@@ -36,45 +33,31 @@ final class CodeCoverageTest extends TestCase
 
         $this->coverage = new CodeCoverage(
             (new Selector)->forLineCoverage($filter),
-            $filter
+            $filter,
         );
     }
 
-    public function testCannotStopWithInvalidSecondArgument(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->coverage->stop(true, null);
-    }
-
-    public function testCannotAppendWithInvalidArgument(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->coverage->append(RawCodeCoverageData::fromXdebugWithoutPathCoverage([]), null);
-    }
-
     public function testCollect(): void
     {
         $coverage = $this->getLineCoverageForBankAccount();
 
         $this->assertEquals(
             $this->getExpectedLineCoverageDataArrayForBankAccount(),
-            $coverage->getData()->lineCoverage()
+            $coverage->getData()->lineCoverage(),
         );
 
         $this->assertEquals(
             [
-                'BankAccountTest::testBalanceIsInitiallyZero'       => ['size' => 'unknown', 'status' => -1, 'fromTestcase' => true],
-                'BankAccountTest::testBalanceCannotBecomeNegative'  => ['size' => 'unknown', 'status' => -1, 'fromTestcase' => true],
-                'BankAccountTest::testBalanceCannotBecomeNegative2' => ['size' => 'unknown', 'status' => -1, 'fromTestcase' => true],
-                'BankAccountTest::testDepositWithdrawMoney'         => ['size' => 'unknown', 'status' => -1, 'fromTestcase' => true],
+                'BankAccountTest::testBalanceIsInitiallyZero'       => ['size' => 'unknown', 'status' => 'unknown'],
+                'BankAccountTest::testBalanceCannotBecomeNegative'  => ['size' => 'unknown', 'status' => 'unknown'],
+                'BankAccountTest::testBalanceCannotBecomeNegative2' => ['size' => 'unknown', 'status' => 'unknown'],
+                'BankAccountTest::testDepositWithdrawMoney'         => ['size' => 'unknown', 'status' => 'unknown'],
             ],
-            $coverage->getTests()
+            $coverage->getTests(),
         );
     }
 
-    public function testWhitelistFiltering(): void
+    public function testIncludeListFiltering(): void
     {
         $this->coverage->filter()->includeFile(TEST_FILES_PATH . 'BankAccount.php');
 
@@ -128,7 +111,7 @@ final class CodeCoverageTest extends TestCase
 
         $this->assertEquals(
             $this->getExpectedLineCoverageDataArrayForBankAccount(),
-            $coverage->getData()->lineCoverage()
+            $coverage->getData()->lineCoverage(),
         );
     }
 
@@ -139,7 +122,7 @@ final class CodeCoverageTest extends TestCase
 
         $this->assertEquals(
             $this->getExpectedLineCoverageDataArrayForBankAccountInReverseOrder(),
-            $coverage->getData()->lineCoverage()
+            $coverage->getData()->lineCoverage(),
         );
     }
 
@@ -147,14 +130,14 @@ final class CodeCoverageTest extends TestCase
     {
         $coverage = new CodeCoverage(
             $this->createStub(Driver::class),
-            new Filter
+            new Filter,
         );
 
         $coverage->merge($this->getLineCoverageForBankAccount());
 
         $this->assertEquals(
             $this->getExpectedLineCoverageDataArrayForBankAccount(),
-            $coverage->getData()->lineCoverage()
+            $coverage->getData()->lineCoverage(),
         );
     }
 }
