@@ -9,7 +9,6 @@
  */
 namespace SebastianBergmann\CodeCoverage\Data;
 
-use SebastianBergmann\CodeCoverage\RawCodeCoverageData;
 use SebastianBergmann\CodeCoverage\TestCase;
 
 final class RawCodeCoverageDataTest extends TestCase
@@ -45,7 +44,6 @@ final class RawCodeCoverageDataTest extends TestCase
                     13 => -1,
                 ],
                 'functions' => [
-
                 ],
             ],
             '/some/path/justAScript.php' => [
@@ -55,7 +53,6 @@ final class RawCodeCoverageDataTest extends TestCase
                     113 => -1,
                 ],
                 'functions' => [
-
                 ],
             ],
         ];
@@ -78,48 +75,6 @@ final class RawCodeCoverageDataTest extends TestCase
         $this->assertEquals($lineData, $dataObject->lineCoverage());
     }
 
-    /**
-     * In the path-coverage XDebug format for Xdebug < 2.9.6, the line data exists inside a "lines" array key where the
-     * file has classes or functions. For files without them, the data is stored in the line-only format.
-     */
-    public function testLineDataFromMixedCoverageXDebugFormat(): void
-    {
-        $rawDataFromDriver = [
-            '/some/path/SomeClass.php' => [
-                'lines' => [
-                    8  => 1,
-                    9  => -2,
-                    13 => -1,
-                ],
-                'functions' => [
-
-                ],
-            ],
-            '/some/path/justAScript.php' => [
-                18  => 1,
-                19  => -2,
-                113 => -1,
-            ],
-        ];
-
-        $lineData = [
-            '/some/path/SomeClass.php' => [
-                8  => 1,
-                9  => -2,
-                13 => -1,
-            ],
-            '/some/path/justAScript.php' => [
-                18  => 1,
-                19  => -2,
-                113 => -1,
-            ],
-        ];
-
-        $dataObject = RawCodeCoverageData::fromXdebugWithMixedCoverage($rawDataFromDriver);
-
-        $this->assertEquals($lineData, $dataObject->lineCoverage());
-    }
-
     public function testClear(): void
     {
         $lineDataFromDriver = [
@@ -359,7 +314,7 @@ final class RawCodeCoverageDataTest extends TestCase
                         ],
                     ],
                 ],
-            ]
+            ],
         );
 
         $coverage->removeCoverageDataForLines(
@@ -369,7 +324,7 @@ final class RawCodeCoverageDataTest extends TestCase
                 31,
                 32,
                 33,
-            ]
+            ],
         );
 
         $this->assertEquals(
@@ -381,7 +336,7 @@ final class RawCodeCoverageDataTest extends TestCase
                 35 => -1,
                 36 => -1,
             ],
-            $coverage->lineCoverage()[$filename]
+            $coverage->lineCoverage()[$filename],
         );
 
         $this->assertEquals(
@@ -443,7 +398,204 @@ final class RawCodeCoverageDataTest extends TestCase
                     ],
                 ],
             ],
-            $coverage->functionCoverage()[$filename]
+            $coverage->functionCoverage()[$filename],
         );
     }
+
+    /**
+     * Xdebug annotates function names inside trait classes.
+     */
+    public function testTraitFunctionNamesDecodedPathCoverageXDebugFormat(): void
+    {
+        $rawDataFromDriver = [
+            '/some/path/FooTrait.php' => [
+                'lines' => [
+                    11 => 1,
+                    12 => -1,
+                    15 => 1,
+                    16 => -2,
+                    18 => 1,
+                ],
+                'functions' => [
+                    'App\\FooTrait->returnsTrue{trait-method:/some/path/FooTrait.php:9-16}' => [
+                        'branches' => [
+                            0 => [
+                                'op_start'   => 0,
+                                'op_end'     => 5,
+                                'line_start' => 11,
+                                'line_end'   => 11,
+                                'hit'        => 1,
+                                'out'        => [
+                                    0 => 6,
+                                    1 => 8,
+                                ],
+                                'out_hit' => [
+                                    0 => 0,
+                                    1 => 1,
+                                ],
+                            ],
+                            6 => [
+                                'op_start'   => 6,
+                                'op_end'     => 7,
+                                'line_start' => 12,
+                                'line_end'   => 12,
+                                'hit'        => 0,
+                                'out'        => [
+                                    0 => 2147483645,
+                                ],
+                                'out_hit' => [
+                                    0 => 0,
+                                ],
+                            ],
+                            8 => [
+                                'op_start'   => 8,
+                                'op_end'     => 12,
+                                'line_start' => 15,
+                                'line_end'   => 16,
+                                'hit'        => 1,
+                                'out'        => [
+                                ],
+                                'out_hit' => [
+                                ],
+                            ],
+                        ],
+                        'paths' => [
+                            0 => [
+                                'path' => [
+                                    0 => 0,
+                                    1 => 6,
+                                ],
+                                'hit' => 0,
+                            ],
+                            1 => [
+                                'path' => [
+                                    0 => 0,
+                                    1 => 8,
+                                ],
+                                'hit' => 1,
+                            ],
+                        ],
+                    ],
+                    '{main}' => [
+                        'branches' => [
+                            0 => [
+                                'op_start'   => 0,
+                                'op_end'     => 2,
+                                'line_start' => 3,
+                                'line_end'   => 18,
+                                'hit'        => 1,
+                                'out'        => [
+                                    0 => 2147483645,
+                                ],
+                                'out_hit' => [
+                                    0 => 0,
+                                ],
+                            ],
+                        ],
+                        'paths' => [
+                            0 => [
+                                'path' => [
+                                    0 => 0,
+                                ],
+                                'hit' => 1,
+                            ],
+                        ],
+                    ],
+                ],
+            ],
+        ];
+
+        $functionData = [
+            '/some/path/FooTrait.php' => [
+                'App\\FooTrait->returnsTrue' => [
+                    'branches' => [
+                        0 => [
+                            'op_start'   => 0,
+                            'op_end'     => 5,
+                            'line_start' => 11,
+                            'line_end'   => 11,
+                            'hit'        => 1,
+                            'out'        => [
+                                0 => 6,
+                                1 => 8,
+                            ],
+                            'out_hit' => [
+                                0 => 0,
+                                1 => 1,
+                            ],
+                        ],
+                        6 => [
+                            'op_start'   => 6,
+                            'op_end'     => 7,
+                            'line_start' => 12,
+                            'line_end'   => 12,
+                            'hit'        => 0,
+                            'out'        => [
+                                0 => 2147483645,
+                            ],
+                            'out_hit' => [
+                                0 => 0,
+                            ],
+                        ],
+                        8 => [
+                            'op_start'   => 8,
+                            'op_end'     => 12,
+                            'line_start' => 15,
+                            'line_end'   => 16,
+                            'hit'        => 1,
+                            'out'        => [
+                            ],
+                            'out_hit' => [
+                            ],
+                        ],
+                    ],
+                    'paths' => [
+                        0 => [
+                            'path' => [
+                                0 => 0,
+                                1 => 6,
+                            ],
+                            'hit' => 0,
+                        ],
+                        1 => [
+                            'path' => [
+                                0 => 0,
+                                1 => 8,
+                            ],
+                            'hit' => 1,
+                        ],
+                    ],
+                ],
+                '{main}' => [
+                    'branches' => [
+                        0 => [
+                            'op_start'   => 0,
+                            'op_end'     => 2,
+                            'line_start' => 3,
+                            'line_end'   => 18,
+                            'hit'        => 1,
+                            'out'        => [
+                                0 => 2147483645,
+                            ],
+                            'out_hit' => [
+                                0 => 0,
+                            ],
+                        ],
+                    ],
+                    'paths' => [
+                        0 => [
+                            'path' => [
+                                0 => 0,
+                            ],
+                            'hit' => 1,
+                        ],
+                    ],
+                ],
+            ],
+        ];
+
+        $dataObject = RawCodeCoverageData::fromXdebugWithPathCoverage($rawDataFromDriver);
+
+        $this->assertEquals($functionData, $dataObject->functionCoverage());
+    }
 }
