@@ -11,8 +11,10 @@ namespace SebastianBergmann\CodeCoverage\Node;
 
 use const DIRECTORY_SEPARATOR;
 use function rtrim;
+use Generator;
+use PHPUnit\Framework\Attributes\DataProvider;
 use ReflectionMethod;
-use SebastianBergmann\CodeCoverage\ProcessedCodeCoverageData;
+use SebastianBergmann\CodeCoverage\Data\ProcessedCodeCoverageData;
 use SebastianBergmann\CodeCoverage\StaticAnalysis\ParsingFileAnalyser;
 use SebastianBergmann\CodeCoverage\TestCase;
 
@@ -20,6 +22,55 @@ final class BuilderTest extends TestCase
 {
     private $factory;
 
+    public static function reducePathsProvider(): Generator
+    {
+        $s = DIRECTORY_SEPARATOR;
+
+        yield [
+            [],
+            '.',
+            self::pathsToProcessedDataObjectHelper([]),
+        ];
+
+        foreach (["C:{$s}", "{$s}"] as $p) {
+            yield [
+                [
+                    'Money.php' => [],
+                ],
+                "{$p}home{$s}sb{$s}Money{$s}",
+                self::pathsToProcessedDataObjectHelper([
+                    "{$p}home{$s}sb{$s}Money{$s}Money.php" => [],
+                ]),
+            ];
+
+            yield [
+                [
+                    'Money.php'    => [],
+                    'MoneyBag.php' => [],
+                ],
+                "{$p}home{$s}sb{$s}Money",
+                self::pathsToProcessedDataObjectHelper([
+                    "{$p}home{$s}sb{$s}Money{$s}Money.php"    => [],
+                    "{$p}home{$s}sb{$s}Money{$s}MoneyBag.php" => [],
+                ]),
+            ];
+
+            yield [
+                [
+                    'Money.php'             => [],
+                    'MoneyBag.php'          => [],
+                    "Cash.phar{$s}Cash.php" => [],
+                ],
+                "{$p}home{$s}sb{$s}Money",
+                self::pathsToProcessedDataObjectHelper([
+                    "{$p}home{$s}sb{$s}Money{$s}Money.php"                    => [],
+                    "{$p}home{$s}sb{$s}Money{$s}MoneyBag.php"                 => [],
+                    "phar://{$p}home{$s}sb{$s}Money{$s}Cash.phar{$s}Cash.php" => [],
+                ]),
+            ];
+        }
+    }
+
     protected function setUp(): void
     {
         $this->factory = new Builder(new ParsingFileAnalyser(true, true));
@@ -45,8 +96,8 @@ final class BuilderTest extends TestCase
         $this->assertEquals(0, $root->numberOfTestedFunctions());
         $this->assertNull($root->parent());
         $this->assertEquals([], $root->directories());
-        #$this->assertEquals(array(), $root->getFiles());
-        #$this->assertEquals(array(), $root->getChildNodes());
+        # $this->assertEquals(array(), $root->getFiles());
+        # $this->assertEquals(array(), $root->getChildNodes());
 
         $this->assertEquals(
             [
@@ -136,7 +187,7 @@ final class BuilderTest extends TestCase
                     'namespace'          => '',
                 ],
             ],
-            $root->classes()
+            $root->classes(),
         );
 
         $this->assertEquals([], $root->functions());
@@ -148,7 +199,7 @@ final class BuilderTest extends TestCase
 
         $method = new ReflectionMethod(
             Builder::class,
-            'buildDirectoryStructure'
+            'buildDirectoryStructure',
         );
 
         $method->setAccessible(true);
@@ -182,19 +233,17 @@ final class BuilderTest extends TestCase
                     "src{$s}Money.php"                    => [],
                     "src{$s}MoneyBag.php"                 => [],
                     "src{$s}Foo{$s}Bar{$s}Baz{$s}Foo.php" => [],
-                ])
-            )
+                ]),
+            ),
         );
     }
 
-    /**
-     * @dataProvider reducePathsProvider
-     */
+    #[DataProvider('reducePathsProvider')]
     public function testReducePaths(array $reducedPaths, string $commonPath, ProcessedCodeCoverageData $paths): void
     {
         $method = new ReflectionMethod(
             Builder::class,
-            'reducePaths'
+            'reducePaths',
         );
 
         $method->setAccessible(true);
@@ -205,58 +254,10 @@ final class BuilderTest extends TestCase
         $this->assertEquals($commonPath, $_commonPath);
     }
 
-    public function reducePathsProvider()
-    {
-        $s = DIRECTORY_SEPARATOR;
-
-        yield [
-            [],
-            '.',
-            $this->pathsToProcessedDataObjectHelper([]),
-        ];
-
-        foreach (["C:{$s}", "{$s}"] as $p) {
-            yield [
-                [
-                    'Money.php' => [],
-                ],
-                "{$p}home{$s}sb{$s}Money{$s}",
-                $this->pathsToProcessedDataObjectHelper([
-                    "{$p}home{$s}sb{$s}Money{$s}Money.php" => [],
-                ]),
-            ];
-
-            yield [
-                [
-                    'Money.php'    => [],
-                    'MoneyBag.php' => [],
-                ],
-                "{$p}home{$s}sb{$s}Money",
-                $this->pathsToProcessedDataObjectHelper([
-                    "{$p}home{$s}sb{$s}Money{$s}Money.php"    => [],
-                    "{$p}home{$s}sb{$s}Money{$s}MoneyBag.php" => [],
-                ]),
-            ];
-
-            yield [
-                [
-                    'Money.php'             => [],
-                    'MoneyBag.php'          => [],
-                    "Cash.phar{$s}Cash.php" => [],
-                ],
-                "{$p}home{$s}sb{$s}Money",
-                $this->pathsToProcessedDataObjectHelper([
-                    "{$p}home{$s}sb{$s}Money{$s}Money.php"                    => [],
-                    "{$p}home{$s}sb{$s}Money{$s}MoneyBag.php"                 => [],
-                    "phar://{$p}home{$s}sb{$s}Money{$s}Cash.phar{$s}Cash.php" => [],
-                ]),
-            ];
-        }
-    }
-
-    private function pathsToProcessedDataObjectHelper(array $paths): ProcessedCodeCoverageData
+    private static function pathsToProcessedDataObjectHelper(array $paths): ProcessedCodeCoverageData
     {
         $coverage = new ProcessedCodeCoverageData;
+
         $coverage->setLineCoverage($paths);
 
         return $coverage;
