@@ -15,18 +15,16 @@ use PhpParser\NodeTraverser;
 use PhpParser\NodeVisitor\NameResolver;
 use PhpParser\NodeVisitor\ParentConnectingVisitor;
 use PhpParser\ParserFactory;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Ticket;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\CodeCoverage\TestFixture\ClassThatUsesAnonymousClass;
 use SebastianBergmann\CodeCoverage\TestFixture\ClassWithNameThatIsPartOfItsNamespacesName\ClassWithNameThatIsPartOfItsNamespacesName;
 
-/**
- * @covers \SebastianBergmann\CodeCoverage\StaticAnalysis\CodeUnitFindingVisitor
- */
+#[CoversClass(CodeUnitFindingVisitor::class)]
 final class CodeUnitFindingVisitorTest extends TestCase
 {
-    /**
-     * @ticket https://github.com/sebastianbergmann/php-code-coverage/issues/786
-     */
+    #[Ticket('https://github.com/sebastianbergmann/php-code-coverage/issues/786')]
     public function testDoesNotFindAnonymousClass(): void
     {
         $codeUnitFindingVisitor = $this->findCodeUnits(__DIR__ . '/../../_files/ClassThatUsesAnonymousClass.php');
@@ -60,9 +58,7 @@ final class CodeUnitFindingVisitorTest extends TestCase
         $this->assertSame(1, $method['ccn']);
     }
 
-    /**
-     * @ticket https://github.com/sebastianbergmann/php-code-coverage/pull/797
-     */
+    #[Ticket('https://github.com/sebastianbergmann/php-code-coverage/pull/797')]
     public function testHandlesClassWithNameThatIsPartOfItsNamespacesName(): void
     {
         $codeUnitFindingVisitor = $this->findCodeUnits(__DIR__ . '/../../_files/ClassWithNameThatIsPartOfItsNamespacesName.php');
@@ -95,13 +91,10 @@ final class CodeUnitFindingVisitorTest extends TestCase
 
         $this->assertSame(
             'functionWithUnionTypes(string|bool $x): string|bool',
-            $functions['SebastianBergmann\CodeCoverage\TestFixture\functionWithUnionTypes']['signature']
+            $functions['SebastianBergmann\CodeCoverage\TestFixture\functionWithUnionTypes']['signature'],
         );
     }
 
-    /**
-     * @requires PHP 8.1
-     */
     public function testHandlesFunctionOrMethodWithIntersectionTypes(): void
     {
         $codeUnitFindingVisitor = $this->findCodeUnits(__DIR__ . '/../../_files/FunctionWithIntersectionTypes.php');
@@ -115,7 +108,7 @@ final class CodeUnitFindingVisitorTest extends TestCase
 
         $this->assertSame(
             'functionWithIntersectionTypes(\SebastianBergmann\CodeCoverage\TestFixture\IntersectionPartOne&\SebastianBergmann\CodeCoverage\TestFixture\IntersectionPartTwo $x): \SebastianBergmann\CodeCoverage\TestFixture\IntersectionPartOne&\SebastianBergmann\CodeCoverage\TestFixture\IntersectionPartTwo',
-            $functions['SebastianBergmann\CodeCoverage\TestFixture\functionWithIntersectionTypes']['signature']
+            $functions['SebastianBergmann\CodeCoverage\TestFixture\functionWithIntersectionTypes']['signature'],
         );
     }
 
@@ -132,24 +125,24 @@ final class CodeUnitFindingVisitorTest extends TestCase
 
         $this->assertSame(
             'f((\SebastianBergmann\CodeCoverage\TestFixture\A&\SebastianBergmann\CodeCoverage\TestFixture\B)|\SebastianBergmann\CodeCoverage\TestFixture\D $x): void',
-            $functions['SebastianBergmann\CodeCoverage\TestFixture\f']['signature']
+            $functions['SebastianBergmann\CodeCoverage\TestFixture\f']['signature'],
         );
 
         $this->assertSame(
             'g(\SebastianBergmann\CodeCoverage\TestFixture\C|(\SebastianBergmann\CodeCoverage\TestFixture\X&\SebastianBergmann\CodeCoverage\TestFixture\D)|null $x): void',
-            $functions['SebastianBergmann\CodeCoverage\TestFixture\g']['signature']
+            $functions['SebastianBergmann\CodeCoverage\TestFixture\g']['signature'],
         );
 
         $this->assertSame(
             'h((\SebastianBergmann\CodeCoverage\TestFixture\A&\SebastianBergmann\CodeCoverage\TestFixture\B&\SebastianBergmann\CodeCoverage\TestFixture\D)|int|null $x): void',
-            $functions['SebastianBergmann\CodeCoverage\TestFixture\h']['signature']
+            $functions['SebastianBergmann\CodeCoverage\TestFixture\h']['signature'],
         );
     }
 
     private function findCodeUnits(string $filename): CodeUnitFindingVisitor
     {
-        $nodes = (new ParserFactory)->create(ParserFactory::PREFER_PHP7)->parse(
-            file_get_contents($filename)
+        $nodes = (new ParserFactory)->createForHostVersion()->parse(
+            file_get_contents($filename),
         );
 
         assert($nodes !== null);
